@@ -296,7 +296,7 @@ class InfEngineServerEngine:
             res = f"{server} --version"
 
             completed_process = subprocess.run(res, shell=True, stdout=subprocess.PIPE)
-            process_stdout = completed_process.stdout.decode("utf-8")
+            process_stdout = completed_process.stdout.decode("utf-8").strip()
 
             if completed_process.returncode:
                 self._logger.error(f"Can't get InfEngine version: {res}")
@@ -304,6 +304,6 @@ class InfEngineServerEngine:
             elif process_stdout.find("Release version:") != -1:
                 match = re.match("Release version: ([0-9a-zA-Z.-]+)", process_stdout)
 
-                return match
+                return match.group()
 
         return None
